==> lms-1.6.1+libs.tar.gz: lms/modules/nodewarn.php <==
<?php

/*
 * LMS version 1.6.1 Ishta
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: nodewarn.php,v 1.16.2.1 2005/05/13 20:10:05 alec Exp $
 */

$setwarnings = isset($_POST['setwarnings']) ? $_POST['setwarnings'] : array();

if(isset($setwarnings['mnodeid']))
{
	$message = isset($setwarnings['message']) ? $setwarnings['message'] : '';
	$warnon = isset($setwarnings['warnon']) ? $setwarnings['warnon'] : FALSE;
	$warnoff = isset($setwarnings['warnoff']) ? $setwarnings['warnoff'] : FALSE;

	foreach($setwarnings['mnodeid'] as $value)
	{
		if($warnon)
			$LMS->NodeSetWarn($value, TRUE);
		if($warnoff) 
			$LMS->NodeSetWarn($value, FALSE);
		
		if($message)
		{
			$LMS->SetTS('users');
			$LMS->DB->Execute('UPDATE users SET message=? WHERE id=?', array($message,$LMS->GetNodeOwner($value)));
		}
	}
	$SESSION->save('warnmessage', $message);
	$SESSION->save('warnon', $warnon);
	$SESSION->save('warnoff', $warnoff);
	
	$SESSION->redirect('?'.$SESSION->get('backto'));
}

$backid = isset($_GET['ownerid']) ? $_GET['ownerid'] : 0;

if($backid)
{
	if($LMS->UserExists($backid))
	{
		$LMS->NodeSetWarnU($backid, $_GET['warning']);
		
		$redir = $SESSION->get('backto');
		if($SESSION->get('lastmodule')=='usersearch')
			$redir .= '&search=1';
			
		$SESSION->redirect('?'.$redir.'#'.$backid);
	}
}

$backid = isset($_GET['id']) ? $_GET['id'] : 0;

if($backid)
{
	if($LMS->NodeExists($backid))
	{
		$LMS->NodeSwitchWarn($backid);
		$SESSION->redirect('?'.$SESSION->get('backto').'#'.$backid);
	}
}

$SESSION->save('backto', $_SERVER['QUERY_STRING']);

$layout['pagetitle'] = trans('Messages');

$nodelist = $LMS->GetNodeList();
unset($nodelist['total']);
unset($nodelist['order']);
unset($nodelist['direction']);
unset($nodelist['totalon']);
unset($nodelist['totaloff']);

$SMARTY->assign('warnmessage', $SESSION->get('warnmessage'));
$SMARTY->assign('warnon', $SESSION->get('warnon'));
$SMARTY->assign('warnoff', $SESSION->get('warnoff'));
$SMARTY->assign('nodelist',$nodelist);
$SMARTY->display('nodewarnings.html');

?>

==> lms-1.7.4+libs.tar.gz: lms/modules/nodewarn.php <==
<?php

/*
 * LMS version 1.7.4 Wraith
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: nodewarn.php,v 1.19 2005/05/26 13:24:57 alec Exp $
 */

$setwarnings = isset($_POST['setwarnings']) ? $_POST['setwarnings'] : array();

if(isset($setwarnings['mnodeid']))
{
	$message = isset($setwarnings['message']) ? $setwarnings['message'] : '';
	$warnon = isset($setwarnings['warnon']) ? $setwarnings['warnon'] : FALSE;
	$warnoff = isset($setwarnings['warnoff']) ? $setwarnings['warnoff'] : FALSE;

	foreach($setwarnings['mnodeid'] as $value)
	{
		if($warnon)
			$LMS->NodeSetWarn($value, TRUE);
		if($warnoff) 
			$LMS->NodeSetWarn($value, FALSE);
		
		if($message)
		{
			$LMS->SetTS('customers');
			$DB->Execute('UPDATE customers SET message=? WHERE id=?', array($message,$LMS->GetNodeOwner($value)));
		}
	}
	$SESSION->save('warnmessage', $message);
	$SESSION->save('warnon', $warnon);
	$SESSION->save('warnoff', $warnoff);
	
	$SESSION->redirect('?'.$SESSION->get('backto'));
}

$backid = isset($_GET['ownerid']) ? $_GET['ownerid'] : 0;

if($backid)
{
	if($LMS->CustomerExists($backid))
	{
		$LMS->NodeSetWarnU($backid, $_GET['warning']);
		
		$redir = $SESSION->get('backto');
		if($SESSION->get('lastmodule')=='customersearch')
			$redir .= '&search=1';
			
		$SESSION->redirect('?'.$redir.'#'.$backid);
	}
}

$backid = isset($_GET['id']) ? $_GET['id'] : 0;

if($backid)
{
	if($LMS->NodeExists($backid))
	{
		$LMS->NodeSwitchWarn($backid);
		$SESSION->redirect('?'.$SESSION->get('backto').'#'.$backid);
	}
}

$SESSION->save('backto', $_SERVER['QUERY_STRING']);

$layout['pagetitle'] = trans('Messages');

$nodelist = $LMS->GetNodeList();
unset($nodelist['total']);
unset($nodelist['order']);
unset($nodelist['direction']);
unset($nodelist['totalon']);
unset($nodelist['totaloff']);

$SMARTY->assign('warnmessage', $SESSION->get('warnmessage'));
$SMARTY->assign('warnon', $SESSION->get('warnon'));
$SMARTY->assign('warnoff', $SESSION->get('warnoff'));
$SMARTY->assign('nodelist',$nodelist);
$SMARTY->display('nodewarnings.html');

?>
